PyXMake Developer Guide: PyXMake.Plugin.__poetry Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Classes | Functions | Variables
PyXMake.Plugin.__poetry Namespace Reference

## Classes
class | ApplicationPlugin
class | Plugin

## Functions
| load (cls, env=None, with_dependencies=False)
| install (cls, path, hash_, size)
| setup (**kwargs)
| build (*args, **kwargs)
| main (**kwargs)

## Variables
| logger = logging.getLogger(__name__)

## Detailed Description

    Poetry configuration and management assistance wrapper.

    @note:
    Created on 09.08.2022

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          -

    @change:
          -

    @author: garb_ma                                                     [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

## Function Documentation

## ◆ build()

PyXMake.Plugin.__poetry.build | ( | * | args,
|  | ** | kwargs )

    Poetry build compatibility helper interface

Definition at line 354 of file __poetry.py.

## ◆ install()

PyXMake.Plugin.__poetry.install | ( |  | cls,
|  |  | path,
|  |  | hash_,
|  |  | size )

    Build a RecordEntry object, from values of the elements.

    Typical usage::

        for row in parse_record_file(f):
            record = RecordEntry.from_elements(row[0], row[1], row[2])

    Meaning of each element is specified in :pep:`376`.

    :param path: first element (file's path)
    :param hash\_: second element (hash of the file's contents)
    :param size: third element (file's size in bytes)
    :raises InvalidRecordEntry: if any element is invalid

Definition at line 273 of file __poetry.py.

## ◆ load()

PyXMake.Plugin.__poetry.load | ( |  | cls,
|  |  | env = None,
|  |  | with_dependencies = False )

    Load installed packages.

Definition at line 208 of file __poetry.py.

## ◆ main()

PyXMake.Plugin.__poetry.main | ( | ** | kwargs | ) |

    Main command line parser.

Definition at line 435 of file __poetry.py.

## ◆ setup()

PyXMake.Plugin.__poetry.setup | ( | ** | kwargs | ) |

    Poetry installation helper interface

Definition at line 319 of file __poetry.py.

## Variable Documentation

## ◆ logger

PyXMake.Plugin.__poetry.logger = logging.getLogger(__name__)

Definition at line 69 of file __poetry.py.